==> openshift-model-storageversionmigrator-5.10.2-sources.jar: io/fabric8/openshift/api/model/storageversionmigrator/v1alpha1/StorageStateStatusBuilder.java <==
package io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class StorageStateStatusBuilder extends io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateStatusFluentImpl<io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateStatus,io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateStatusBuilder>{
  public StorageStateStatusBuilder() {
    this(false);
  }
  public StorageStateStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new StorageStateStatus(), validationEnabled);
  }
  public StorageStateStatusBuilder(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public StorageStateStatusBuilder(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new StorageStateStatus(), validationEnabled);
  }
  public StorageStateStatusBuilder(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateStatusFluent<?> fluent,io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateStatus instance) {
    this(fluent, instance, false);
  }
  public StorageStateStatusBuilder(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateStatusFluent<?> fluent,io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCurrentStorageVersionHash(instance.getCurrentStorageVersionHash()); 
    fluent.withLastHeartbeatTime(instance.getLastHeartbeatTime()); 
    fluent.withPersistedStorageVersionHashes(instance.getPersistedStorageVersionHashes()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public StorageStateStatusBuilder(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateStatus instance) {
    this(instance,false);
  }
  public StorageStateStatusBuilder(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCurrentStorageVersionHash(instance.getCurrentStorageVersionHash()); 
    this.withLastHeartbeatTime(instance.getLastHeartbeatTime()); 
    this.withPersistedStorageVersionHashes(instance.getPersistedStorageVersionHashes()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.StorageStateStatus build() {
    StorageStateStatus buildable = new StorageStateStatus(fluent.getCurrentStorageVersionHash(),fluent.getLastHeartbeatTime(),fluent.getPersistedStorageVersionHashes());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StorageStateStatusBuilder that = (StorageStateStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-storageversionmigrator-6.3.1-sources.jar: io/fabric8/openshift/api/model/storageversionmigrator/v1alpha1/StorageStateStatusBuilder.java <==
package io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class StorageStateStatusBuilder extends StorageStateStatusFluentImpl<StorageStateStatusBuilder> implements VisitableBuilder<StorageStateStatus,StorageStateStatusBuilder>{
  public StorageStateStatusBuilder() {
    this(false);
  }
  public StorageStateStatusBuilder(Boolean validationEnabled) {
    this(new StorageStateStatus(), validationEnabled);
  }
  public StorageStateStatusBuilder(StorageStateStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public StorageStateStatusBuilder(StorageStateStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new StorageStateStatus(), validationEnabled);
  }
  public StorageStateStatusBuilder(StorageStateStatusFluent<?> fluent,StorageStateStatus instance) {
    this(fluent, instance, false);
  }
  public StorageStateStatusBuilder(StorageStateStatusFluent<?> fluent,StorageStateStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCurrentStorageVersionHash(instance.getCurrentStorageVersionHash()); 
    fluent.withLastHeartbeatTime(instance.getLastHeartbeatTime()); 
    fluent.withPersistedStorageVersionHashes(instance.getPersistedStorageVersionHashes()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public StorageStateStatusBuilder(StorageStateStatus instance) {
    this(instance,false);
  }
  public StorageStateStatusBuilder(StorageStateStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withCurrentStorageVersionHash(instance.getCurrentStorageVersionHash()); 
    this.withLastHeartbeatTime(instance.getLastHeartbeatTime()); 
    this.withPersistedStorageVersionHashes(instance.getPersistedStorageVersionHashes()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  StorageStateStatusFluent<?> fluent;
  Boolean validationEnabled;
  public StorageStateStatus build() {
    StorageStateStatus buildable = new StorageStateStatus(fluent.getCurrentStorageVersionHash(),fluent.getLastHeartbeatTime(),fluent.getPersistedStorageVersionHashes());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
